Commands

Enum Commands 

pub enum Commands {
Show 22 variants Pack { input: PathBuf, output: PathBuf, base: Option<PathBuf>, compression: String, encrypt: bool, block_size: u32, workers: Option<usize>, dcam: bool, dcam_optimal: bool, silent: bool, }, Extract { input: PathBuf, output: PathBuf, }, Show { snap: PathBuf, json: bool, }, Diff { a: PathBuf, b: PathBuf, }, Log { dir: PathBuf, }, Convert { format: String, input: PathBuf, output: PathBuf, compression: String, block_size: u32, silent: bool, }, Predict { path: PathBuf, block_size: u32, min_chunk: Option<u32>, avg_chunk: Option<u32>, max_chunk: Option<u32>, json: bool, }, Mount { snap: String, mountpoint: PathBuf, overlay: Option<PathBuf>, editable: bool, daemon: bool, cache_size: Option<String>, uid: u32, gid: u32, }, Unmount { mountpoint: PathBuf, }, Shell { snap: String, overlay: Option<PathBuf>, editable: bool, cache_size: Option<String>, }, Commit { output: PathBuf, mountpoint: Option<PathBuf>, base: Option<PathBuf>, }, Checkout { archive: PathBuf, path: PathBuf, }, Status { path: Option<PathBuf>, }, Init { path: Option<PathBuf>, }, Remote { action: RemoteCommand, }, Push { remote: String, archive: Option<PathBuf>, }, Pull { remote: String, archive: Option<String>, }, Serve { snap: String, port: u16, bind: String, daemon: bool, }, Keygen { output_dir: Option<PathBuf>, }, Sign { key: PathBuf, image: PathBuf, }, Verify { key: PathBuf, image: PathBuf, }, Doctor,
}

Variants



Pack

Pack a file or directory into a deduplicated archive

Fields

input: PathBuf

Path to input data

output: PathBuf

Output archive path (.hxz)

base: Option<PathBuf>

Base archive to diff against

compression: String

Compression algorithm (lz4, zstd, none)

encrypt: bool

Enable encryption

block_size: u32

Block size in bytes

workers: Option<usize>

Number of compression worker threads (0 = auto)

dcam: bool

Run adaptive CDC analysis

dcam_optimal: bool

Run extensive DCAM analysis to find globally optimal parameters (up to 16MB chunks)

silent: bool

Suppress output



Extract

Extract an archive back to a file or directory

Fields

input: PathBuf

Input .hxz archive

output: PathBuf

Output path



Show

Show archive details and metadata

Fields

snap: PathBuf

Path to archive

json: bool

Output as JSON



Diff

Compare two archives and show storage savings

Fields

a: PathBuf

First archive

b: PathBuf

Second archive



Log

List archives in a directory and show their lineage

Fields

dir: PathBuf

Directory to scan



Convert

Convert external data formats into Hexz archives

Fields

format: String

Input format (tar)

input: PathBuf

Input path

output: PathBuf

Output archive path

compression: String

Compression algorithm

block_size: u32

Block size

silent: bool

Suppress output



Predict

Predict compression and deduplication potential

Fields

path: PathBuf

Path to analyze

block_size: u32

Block size to test

min_chunk: Option<u32>

Minimum chunk size for CDC

avg_chunk: Option<u32>

Average chunk size for CDC

max_chunk: Option<u32>

Maximum chunk size for CDC

json: bool

Output as JSON



Mount

Mount an archive as a FUSE filesystem

Fields

snap: String

Archive to mount

mountpoint: PathBuf

Mount point directory

overlay: Option<PathBuf>

Optional write layer directory for modifications

editable: bool

Make the mount writable by automatically using a temporary overlay

daemon: bool

Run as daemon

cache_size: Option<String>

Cache size (e.g., “1G”)

uid: u32

User ID for files

gid: u32

Group ID for files



Unmount

Unmount a previously mounted archive

Fields

mountpoint: PathBuf

Mount point to unmount



Shell

Drop into a shell within a mounted archive

Fields

snap: String

Archive to mount

overlay: Option<PathBuf>

Optional write layer directory for modifications

editable: bool

Make the mount writable by automatically using a temporary overlay

cache_size: Option<String>

Cache size (e.g., “1G”)



Commit

Commit changes from a writable mount to a new thin archive

Fields

output: PathBuf

Output archive path (.hxz)

mountpoint: Option<PathBuf>

Mount point directory or workspace path (defaults to current directory)

base: Option<PathBuf>

Base archive to link against (optional if can be inferred)



Checkout

Initialize a workspace from an archive (Git-style)

Fields

archive: PathBuf

Archive to use as base

path: PathBuf

Directory to create the workspace in



Status

Show changes in the current workspace

Fields

path: Option<PathBuf>

Workspace path (defaults to current directory)



Init

Initialize a new empty workspace

Fields

path: Option<PathBuf>

Directory to create the workspace in (defaults to current directory)



Remote

Manage remote endpoints for the workspace

Fields



Push

Push thin archives to a remote endpoint

Fields

remote: String

Remote name (defaults to “origin”)

archive: Option<PathBuf>

Archive to push (defaults to the workspace’s base archive)



Pull

Pull thin archives from a remote endpoint

Fields

remote: String

Remote name (defaults to “origin”)

archive: Option<String>

Specific archive to pull (omit to pull all new archives)



Serve

Serve an archive over the network (HTTP range requests)

Fields

snap: String

Archive to serve

port: u16

Server port

bind: String

Bind address

daemon: bool

Run as daemon



Keygen

Generate an Ed25519 signing keypair

Fields

output_dir: Option<PathBuf>

Output directory for keys



Sign

Sign an archive

Fields

key: PathBuf

Private key path

image: PathBuf

Archive to sign



Verify

Verify an archive’s signature

Fields

key: PathBuf

Public key path

image: PathBuf

Archive to verify



Doctor

Run system health check and diagnostics