pub struct Workspace {
pub root: PathBuf,
pub config: WorkspaceConfig,
}Expand description
A Hexz workspace rooted at a directory with associated configuration.
Fields
root: PathBufRoot directory of the workspace.
config: WorkspaceConfigWorkspace configuration loaded from config.json.
Implementations
Sourceimpl Workspace
impl Workspace
Sourcepub fn init(path: &Path, base_archive: Option<PathBuf>) -> Result<Self>
pub fn init(path: &Path, base_archive: Option<PathBuf>) -> Result<Self>
Initialize a new workspace at the given path with an optional base archive.
Sourcepub fn find(start_path: &Path) -> Result<Option<Self>>
pub fn find(start_path: &Path) -> Result<Option<Self>>
Search upward from start_path to find an existing workspace.
Sourcepub fn overlay_path(&self) -> PathBuf
pub fn overlay_path(&self) -> PathBuf
Return the path to the overlay directory for this workspace.
Sourcepub fn metadata_dir(&self) -> PathBuf
pub fn metadata_dir(&self) -> PathBuf
Return the path to the centralized metadata directory for this workspace.